| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Kubernetes.Model.V1.FlockerVolumeSource
Documentation
data FlockerVolumeSource Source
Represents a Flocker volume mounted by the Flocker agent. Flocker volumes do not support ownership management or SELinux relabeling.
Constructors
| FlockerVolumeSource | |
Fields
| |
mkFlockerVolumeSource :: Text -> FlockerVolumeSource Source
Use this method to build a FlockerVolumeSource